"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var react_native_1 = require("react-native");
var styles = require("./RouterStyles");
var RouterStore_1 = require("./RouterStore");
var immutable_1 = require("immutable");
var Router = /** @class */ (function (_super) {
    __extends(Router, _super);
    function Router(props) {
        var _this = _super.call(this, props) || this;
        _this.disposables = immutable_1.List();
        _this.state = {
            currentScene: props.config.defaultSceneName,
        };
        return _this;
    }
    Router.go = function (scene, params) {
        RouterStore_1.routerStore.updateCurrentScene(scene, params);
    };
    Router.back = function () {
        RouterStore_1.routerStore.popScene();
    };
    Router.prototype.componentDidMount = function () {
        var _this = this;
        this.disposables.push(RouterStore_1.routerStore.currentScene().subscribe(function (scene) { return _this.onCurrentSceneChange(scene); }));
    };
    Router.prototype.componentWillUnmount = function () {
        this.disposables.forEach(function (d) { return d.dispose(); });
    };
    Router.prototype.render = function () {
        return (React.createElement(react_native_1.View, { style: [styles.container, this.props.style] },
            this.renderHeaderScene(),
            React.createElement(react_native_1.View, { style: styles.container }, this.renderCurrentScene()),
            this.renderFooterScene()));
    };
    Router.prototype.onCurrentSceneChange = function (currentScene) {
        if (currentScene !== this.state.currentScene) {
            this.setState({ currentScene: currentScene });
        }
    };
    Router.prototype.findCurrentSceneConfig = function () {
        var scenes = immutable_1.List(this.props.config.scenes);
        var targetScene = this.state.currentScene || this.props.config.defaultSceneName;
        var currentScene = scenes.find(function (scene) { return scene.name === targetScene; });
        if (!currentScene) {
            throw new Error("Route " + this.state.currentScene + " not found");
        }
        return currentScene;
    };
    Router.prototype.renderHeaderScene = function () {
        var currentSceneConfig = this.findCurrentSceneConfig();
        if (currentSceneConfig && currentSceneConfig.header) {
            return React.createElement(currentSceneConfig.header, this.getParams());
        }
    };
    Router.prototype.renderCurrentScene = function () {
        var currentSceneConfig = this.findCurrentSceneConfig();
        return React.createElement(currentSceneConfig.scene, this.getParams());
    };
    Router.prototype.renderFooterScene = function () {
        var currentSceneConfig = this.findCurrentSceneConfig();
        if (currentSceneConfig && currentSceneConfig.footer) {
            return React.createElement(currentSceneConfig.footer, this.getParams());
        }
    };
    Router.prototype.getParams = function () {
        var currentSceneConfig = this.findCurrentSceneConfig();
        var params = Object.assign({}, currentSceneConfig.params || {}, RouterStore_1.routerStore.getParams());
        return { params: params };
    };
    return Router;
}(React.Component));
exports.Router = Router;
